{$ ::ctrl.pool.description $}

Protocol
  {$ ::ctrl.pool.protocol $}
Load Balancer Algorithm
  {$ ctrl.pool.lb_algorithm | decode:ctrl.loadBalancerAlgorithm $}
Session Persistence
  {$ ctrl.pool.session_persistence | noValue:('None' | translate) $}
Admin State Up
  {$ ctrl.pool.admin_state_up | yesno $}
Health Monitor ID
  {$ ::ctrl.pool.healthmonitor_id $} {$ 'None' | translate $}
Pool ID
  {$ ::ctrl.pool.id $}
Tenant ID
  {$ ::ctrl.pool.tenant_id $}